#!/bin/bash

# gen_sensorillu.bash
#
# Take (modified) rtcontrib sensor readings and produce a time series file
# for each sensor.
#
# (c) Jan 2010, Axel Jacobs

sensors="data/photocells.pts"
sensor_dc="results/sensors"
sensors_vec="tmp/sensors.vec"
rm -f $sensors_vec
year_vecs="weather/gatwick_year.vecs"

# Work out how many sensor points we have
# Make sure there are no blank lines in that file!
npts=$(cat $sensors |wc -l)

# Convert to illuminance, combine the DCs into a vector and transpose
for i in {000..145}; do
    cat results/sensors/p$i.dat |rcalc -e '$1=179*($1*0.265+$2*0.67+$3*0.065)' \
            |tr '\n' '\t' >> $sensors_vec
    # Append a line break
    echo >> $sensors_vec
done

sensorfiles=""
# Loop over all sensors
for s in $(seq $npts); do
    # Extract and transpose the sensor vector
    cat $sensors_vec |cut -f$s |tr '\n' '\t' > tmp/tmp.vec
    echo >> tmp/tmp.vec

    tmpfile="tmp/sensor${s}_illu.dat"
    rm -f $tmpfile

    while read line; do
        # Multiply the time step vector with the partial sensor readings
        # and add them all up. This gives us the illu for each time step.
        echo $line |cat - tmp/tmp.vec |total -p |tr '\t' '\n' |total \
                >> $tmpfile
    done < $year_vecs

    sensorfiles="$sensorfiles $tmpfile"
    # Put the month, day, time columns in from to get a time series file
    # Dynamic daylight metrics can then be done in any spread sheet.
    cat weather/timedate.csv |rlam - $sensorfiles > results/sensors_illu.tmsr
done

#EOF
