#!/bin/awk -f

# gen_tfs.awk
#
# Derive Temporal Fraction of Satisfaction as an example for a
# dynamic daylight metric. This was proposed in:
# Laurent Michel, Jean-Louis Scartezzini: Implementing the partial daylight
# factor method under a scanning sky simulator. 
# Solar Energy, 72(6):473–492, 2002.
#
# (c) Feb 2010, Axel Jacobs

BEGIN {
}

{
	# Assume that we work every day from 9 to 5. You need to keep track
	# of the weekdays if your building is not occupied Sat and Sun.
	# $1: month, starting with 1
	# $2: day, starting with 1
	# $3: decimal hour, from 0.5 to 23.5 in one-hour steps
	if ($3>9 && $3<17) {
		# Keep track of the working hours. We need result as a percentage.
		hours+=1;
		# Loop over all sensors
		for (i=4; i<=NF; i++) {
			# Is illu above the minimum?
			if ($i>500) min[i]+=1
			# Is illu below the maximum?
			if($i<1500) max[i]+=1
			# Are both criteria satisfied?
			if($i>500 && $i<1500) minmax[i]+=1
		}
	}
}

END {
	for (i=4; i<=NF; i++) {
		# Print the results in a nicely formatted list.
		printf "Sensor%02d - TFS_min: %5.1f%%, TFS_max: %5.1f%%, TFS_minmax: %5.1f%%\n", \
		i-3, min[i]/hours*100, max[i]/hours*100, minmax[i]/hours*100
	}
}

#EOF
